@@ -570,10 +570,9 @@ void
 display_stat(struct writer *w, const char *tag, const char *descr,
 	long unsigned int cnt)
 {
-	char buf[20];
+	char buf[20] = {};
 
 	tag_start(w, tag, descr);
-	memset(buf, 0, sizeof(buf));
 	snprintf(buf, sizeof(buf), "%lu", cnt );
 	tag_attr(w, tag, "", buf);
 	tag_end(w);
@@ -727,6 +726,9 @@ display_configuration(lldpctl_conn_t *conn, struct writer *w)
 	tag_datatag(w, "advertise-version", "Advertise version",
 	    lldpctl_atom_get_int(configuration, lldpctl_k_config_advertise_version)?
 	    "yes":"no");
+	tag_datatag(w, "ifdescr-update", "Update interface descriptions",
+	    lldpctl_atom_get_int(configuration, lldpctl_k_config_ifdescr_update)?
+	    "yes":"no");
 	tag_datatag(w, "lldpmed-no-inventory", "Disable LLDP-MED inventory",
 	    (lldpctl_atom_get_int(configuration, lldpctl_k_config_lldpmed_noinventory) == 0)?
 	    "no":"yes");
