@@ -60,9 +60,8 @@ cdp_send(struct lldpd *global,
 #endif
 
 	length = hardware->h_mtu;
-	if ((packet = (u_int8_t*)malloc(length)) == NULL)
+	if ((packet = (u_int8_t*)calloc(1, length)) == NULL)
 		return ENOMEM;
-	memset(packet, 0, length);
 	pos = packet;
 
 	/* Ethernet header */
