@@ -198,9 +198,8 @@ sonmp_send(struct lldpd *global,
 
 	chassis = hardware->h_lport.p_chassis;
 	length = hardware->h_mtu;
-	if ((packet = (u_int8_t*)malloc(length)) == NULL)
+	if ((packet = (u_int8_t*)calloc(1, length)) == NULL)
 		return ENOMEM;
-	memset(packet, 0, length);
 	pos = packet;
 
 	/* Ethernet header */
