@@ -373,12 +373,11 @@ _lldpctl_atom_set_str_config(lldpctl_atom_t *atom, lldpctl_key_t key,
 {
 	struct _lldpctl_atom_config_t *c =
 	    (struct _lldpctl_atom_config_t *)atom;
-	struct lldpd_config config;
+	struct lldpd_config config = {};
 	char *iface_pattern = NULL;
 	char *description = NULL;
 	int rc, len;
 
-	memset(&config, 0, sizeof(struct lldpd_config));
 	len = strlen(value) + 1;
 
 	switch (key) {
@@ -438,6 +437,8 @@ _lldpctl_atom_get_int_config(lldpctl_atom_t *atom, lldpctl_key_t key)
 		return c->config->c_receiveonly;
 	case lldpctl_k_config_advertise_version:
 		return c->config->c_advertise_version;
+	case lldpctl_k_config_ifdescr_update:
+		return c->config->c_set_ifdescr;
 #ifdef ENABLE_LLDPMED
 	case lldpctl_k_config_lldpmed_noinventory:
 		return c->config->c_noinventory;
@@ -460,8 +461,7 @@ _lldpctl_atom_set_int_config(lldpctl_atom_t *atom, lldpctl_key_t key,
 	int rc;
 	struct _lldpctl_atom_config_t *c =
 	    (struct _lldpctl_atom_config_t *)atom;
-	struct lldpd_config config;
-	memset(&config, 0, sizeof(struct lldpd_config));
+	struct lldpd_config config = {};
 
 	switch (key) {
 	case lldpctl_k_config_paused:
@@ -471,6 +471,9 @@ _lldpctl_atom_set_int_config(lldpctl_atom_t *atom, lldpctl_key_t key,
 		config.c_tx_interval = value;
 		if (value > 0) c->config->c_tx_interval = value;
 		break;
+	case lldpctl_k_config_ifdescr_update:
+		config.c_set_ifdescr = c->config->c_set_ifdescr = value;
+		break;
 #ifdef ENABLE_LLDPMED
 	case lldpctl_k_config_fast_start_enabled:
 		config.c_enable_fast_start =  value?1:2;
@@ -749,7 +752,7 @@ _lldpctl_atom_set_atom_port(lldpctl_atom_t *atom, lldpctl_key_t key, lldpctl_ato
 	struct _lldpctl_atom_port_t *p =
 	    (struct _lldpctl_atom_port_t *)atom;
 	struct lldpd_hardware *hardware = p->hardware;
-	struct lldpd_port_set set;
+	struct lldpd_port_set set = {};
 	int rc;
 
 #ifdef ENABLE_DOT3
@@ -767,8 +770,6 @@ _lldpctl_atom_set_atom_port(lldpctl_atom_t *atom, lldpctl_key_t key, lldpctl_ato
 		return NULL;
 	}
 
-	memset(&set, 0, sizeof(struct lldpd_port_set));
-
 	switch (key) {
 #ifdef ENABLE_DOT3
 	case lldpctl_k_port_dot3_power:
@@ -1951,7 +1952,7 @@ _lldpctl_atom_get_str_med_location(lldpctl_atom_t *atom, lldpctl_key_t key)
 		return fixed_precision(atom, l, 9, 25, 0, " W", " E");
 	case lldpctl_k_med_location_altitude:
 		if (m->location->format != LLDP_MED_LOCFORMAT_COORD) break;
-		memset(&l, 0, sizeof(u_int64_t));
+		l = 0;
 		memcpy(&l, m->location->data + 10, 5);
 		l = (ntohll(l) & 0x3FFFFFFF000000ULL) >> 24;
 		return fixed_precision(atom, l, 22, 8, 1, NULL, NULL);
